@@ -18,7 +18,7 @@
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
- $Id: testparser.c,v 1.3 2000/04/18 08:47:13 fredgo Exp $
+ $Id: testparser.c,v 1.3.2.1 2001/11/28 18:06:30 fredgo Exp $
 */
 
 #include "bibtex.h"
@@ -78,7 +78,7 @@ main (int argc, char * argv [])
       field->text = g_strdup ("Essai \\  GRONF oui FIN");
       field->converted = TRUE;
       
-      field = bibtex_reverse_field (field, 1);
+      field = bibtex_reverse_field (field, 1, 1);
       tmp = bibtex_struct_as_bibtex (field->structure);
       
       g_message ("converted: %s", tmp);
