@@ -18,7 +18,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: pybliographer.py,v 1.16 1999/08/31 13:08:13 gobry Exp $
+# $Id: pybliographer.py,v 1.6.2.2 2000/10/09 07:25:57 fredgo Exp $
 
 version  = "@version@"
 progname = "@package@"
@@ -27,20 +27,34 @@ lib_pybdir  = "@libpyb@"
 data_pybdir = "@datapyb@"
 localedir   = "@localedir@"
 
+import sys
+
+sys.path.append (data_pybdir)
+sys.path.append (lib_pybdir)
+sys.path.insert (0, '.')
+sys.path.insert (0, './compiled')
+
+import gettext
+	
+gettext.bindtextdomain(progname, localedir)
+gettext.textdomain(progname)
+
+_ = gettext.gettext
 
 def print_version ():
-	print "This is %s, version %s" % (progname, version)
+	print _("This is %s, version %s") % (progname, version)
 
 def copyright ():
-	print """Copyright (C) 1998-1999 Frederic GOBRY
-This is free software with ABSOLUTELY NO WARRANTY.
-For details, type `warranty'."""
+	print 'Copyright (C) 1998-2000 Frederic GOBRY'
+	print _("This is free software with ABSOLUTELY NO WARRANTY.")
+	print _("For details, type `warranty'.")
 
 def warranty ():
 	print_version ()
-	print """Copyright (C) 1998-1999 Frederic GOBRY
-This is free software with ABSOLUTELY NO WARRANTY.
-
+	print 'Copyright (C) 1998-2000 Frederic GOBRY'
+	
+	print _("This is free software with ABSOLUTELY NO WARRANTY.")
+	print """
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
@@ -56,19 +70,11 @@ along with this program. If not, write to the Free Software
 Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 """
 	
-import sys
 import os
 import getopt, string
 
-
 sys.ps1 = 'python > '
 
-sys.path.append (data_pybdir)
-sys.path.append (lib_pybdir)
-sys.path.insert (0, '.')
-sys.path.insert (0, './compiled')
-
-
 optlist, args = getopt.getopt (sys.argv [1:],
 			       'qf:nvh',
 			       ['quiet',
@@ -76,7 +82,10 @@ optlist, args = getopt.getopt (sys.argv [1:],
 				'version',
 				'help'])
 
-sys.argv = args
+sys.argv = sys.argv [0:1] + args
+try:
+	sys.argv.remove ('--')
+except ValueError: pass
 
 quiet = 0
 
@@ -85,6 +94,7 @@ except os.error: sources = [ os.path.join (data_pybdir, "pybrc.py") ]
 else:  	         sources = [ "pybrc.py" ]
 
 sources.append (os.path.expanduser('~/.pybrc.py'))
+load_config = 1
 
 for opt, value in optlist:
 	if opt == '-q' or opt == '--quiet':
@@ -93,13 +103,14 @@ for opt, value in optlist:
 	
 	if opt == '-n':
 		sources = []
+		load_config = 0
 		continue
 
 	if opt == '-f' or opt == '--file':
 		try:
 			os.stat (value)
 		except os.error:
-			print "%s: error: can't open file `%s'" \
+			print _("%s: error: can't open file `%s'") \
 			      % (progname, value)
 			sys.exit (1)
 		
@@ -112,7 +123,7 @@ for opt, value in optlist:
 
 	if opt == '-h' or opt == '--help':
 		print_version ()
-		print "For help, run %s and type `help' at the prompt" \
+		print _("For help, run %s and type `help' at the prompt") \
 		      % progname
 		sys.exit (0)
 		
@@ -121,15 +132,12 @@ for opt, value in optlist:
 if not quiet:
 	print_version ()
 	copyright ()
-	print "Useful commands:\n	help     to get some help\n	quit     to quit\n"
+	print _("Useful commands:\n	help     to get some help\n	quit     to quit\n")
 
 # ---------- Lire les fichiers de conf
 
 user_global = {'__builtins__' : __builtins__,
 	       '__name__'     : progname,
-	       'pyb_prefix'   : data_pybdir,
-	       'quiet'        : quiet,
-	       'version'      : version
 	       }
 
 user_local  = {}
@@ -144,14 +152,17 @@ for filename in sources:
 	else:
 		execfile (filename, user_global)
 
+if load_config:
+	from Pyblio import Config
+	Config.load_user ()
+
 # Fichiers passes en argument au programme
 if len (args) > 0 :
 	filename = args [0]
-	
 	try:
 		os.stat (filename)
 	except os.error:
-		print "%s: error: can't open file `%s'" % (progname, filename)
+		print _("%s: error: can't open file `%s'") % (progname, filename)
 		sys.exit (1)
 	else:
 		execfile (filename, user_global)
